jk_jsoncfghelper2
==========

Introduction
------------

This python module contains support classes for loading and verifying configuratios. It is currently in alpha state as it is not yet clear how complete the implementation and how stable the API is. This modul might still undergo quite some rework.
Information about this module can be found here:

* [github.org](https://github.com/jkpubsrc/python-module-jk-jsoncfghelper2)
* [pypi.python.org](https://pypi.python.org/pypi/jk_jsoncfghelper2)

Why this module?
----------------

...

Limitations of this module
--------------------------

...

How to use this module
----------------------

### Import this module

Please include this module into your application using the following code:

```python
impoert jk_jsoncfghelper2
```

...

Contact Information
-------------------

This is Open Source code. That not only gives you the possibility of freely using this code it also
allows you to contribute. Feel free to contact the author(s) of this software listed below, either
for comments, collaboration requests, suggestions for improvement or reporting bugs:

* Jürgen Knauth: jknauth@uni-goettingen.de, pubsrc@binary-overflow.de

License
-------

This software is provided under the following license:

* Apache Software License 2.0



